<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>MEConfig</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX User Manager</source>
        <translation>MX Správca Užívateľov</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Administration</source>
        <translation>Správa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>Add a new user</source>
        <translation>Pridať nového užívateľa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Add User Account</source>
        <translation>Pridať užívateľské konto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>Reenter password for new user</source>
        <translation>Znovu zadať heslo nového užívateľa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>confirm password</source>
        <translation>potvrdiť heslo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="154"/>
        <location filename="../mainwindow.ui" line="1118"/>
        <source>Username of new user</source>
        <translation>Uživateľské meno</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>User login name:</source>
        <translation>Prihlasovacie meno:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <location filename="../mainwindow.ui" line="416"/>
        <location filename="../mainwindow.ui" line="1134"/>
        <source>Enter username of new user</source>
        <translation>Zadajte uživateľské meno</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <location filename="../mainwindow.ui" line="422"/>
        <source>username</source>
        <translation>uživateľské meno</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="189"/>
        <location filename="../mainwindow.ui" line="227"/>
        <source>Password for new user</source>
        <translation>Heslo nového užívateľa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="192"/>
        <source>User password:</source>
        <translation>Užívateľské heslo:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="205"/>
        <source>Enter password for new user</source>
        <translation>Zadajte heslo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <source>password</source>
        <translation>heslo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>Confirm user password:</source>
        <translation>potvrdiť heslo:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="262"/>
        <source>Delete User Account</source>
        <translation>Zmazať užívateľské konto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="305"/>
        <source>Select user</source>
        <translation>Vyberte užívateľa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="321"/>
        <location filename="../mainwindow.ui" line="1209"/>
        <location filename="../mainwindow.ui" line="1222"/>
        <location filename="../mainwindow.ui" line="1346"/>
        <location filename="../mainwindow.ui" line="1368"/>
        <source>Select user to delete</source>
        <translation>Zvoľte užívateľa k zmazaniu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="330"/>
        <source>User to delete:</source>
        <translation>Užívateľ k zmazaniu:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="343"/>
        <source>Also delete the user&apos;s home directory</source>
        <translation>Zároveň zmazať home zložku užívateľa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <source>Delete user home directory</source>
        <translation>Zmazať home zložku užívateľa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="359"/>
        <source>Rename User Account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="371"/>
        <location filename="../mainwindow.ui" line="483"/>
        <source>Select user to modify:</source>
        <translation>Zvoľte užívateľa k zmene:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>New user name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="432"/>
        <source>Change User Password</source>
        <translation>Zmeniť užívateľské heslo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="447"/>
        <source>new password</source>
        <translation>nové heslo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="460"/>
        <source>Confirm new password:</source>
        <translation>potvrdiť nové heslo:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <source>confirm new password</source>
        <translation>potvrdiť nové heslo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="496"/>
        <source>New user password:</source>
        <translation>Nové užívateľské heslo:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="527"/>
        <source>Options</source>
        <translation>Nastavenia</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="530"/>
        <source>Repair a user configuration</source>
        <translation>Opraviť konfiguráciu užívateľa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="564"/>
        <location filename="../mainwindow.ui" line="1271"/>
        <source>Modify User Account</source>
        <translation>Zmeniť užívateľské konto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="576"/>
        <location filename="../mainwindow.ui" line="592"/>
        <source>Select user to repair</source>
        <translation>Zvoľte užívateľa k oprave</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="579"/>
        <location filename="../mainwindow.ui" line="1355"/>
        <source>User to change:</source>
        <translation>Užívateľ k zmene:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="624"/>
        <source>Restore Defaults</source>
        <translation>Obnoviť predvolené</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="645"/>
        <source>Restore browser configs to MX defaults</source>
        <translation>Obnoviť nastavenia prehliadača na MX predvolené </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="651"/>
        <source>Mozilla (Iceweasel or Firefox) configs</source>
        <translation>Konfigurácía Mozilla (Iceweasel alebo Firefox)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="654"/>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="661"/>
        <source>Restore group memberships to MX defaults</source>
        <translation>Obnoviť členstvo skupiny na MX predvolené </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="667"/>
        <source>Group memberships</source>
        <translation>Členstvo skupiny</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="670"/>
        <source>Alt+G</source>
        <translation>Alt+G</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="680"/>
        <source>Change Autologin Settings</source>
        <translation>Zmeniť nastavenia automatického prihlasovania</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="686"/>
        <source>Log in automatically</source>
        <translation>Prihlasovať automaticky</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="693"/>
        <source>Require password to log in</source>
        <translation>Pri prihlásení požadovať heslo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="708"/>
        <source>Copy/Sync</source>
        <translation>Kopírovať/Synchronizovať</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="735"/>
        <source>Copy Between Desktops</source>
        <translation>Kopírovať plochy</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="762"/>
        <location filename="../mainwindow.ui" line="829"/>
        <source>Select desktop to copy from</source>
        <translation>Vyberte plochu z ktorej sa bude kopírovať</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="775"/>
        <source>Select to only copy files</source>
        <translation>Vyberte iba skoírovať súbory</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="778"/>
        <source>Copy only</source>
        <translation>Iba skopírovať</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="794"/>
        <location filename="../mainwindow.ui" line="807"/>
        <source>Select desktop to copy to</source>
        <translation>Vyberte plochu do ktorej sa bude kopírovať</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="816"/>
        <source>Copy to:</source>
        <translation>Kopírovať do:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="838"/>
        <source>Copy from:</source>
        <translation>Kopírovať z:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="851"/>
        <source>Select to copy and then delete differences</source>
        <translation>Zvoľte kopírovať a potom zmazať rozdiely</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="854"/>
        <source>Sync</source>
        <translation>Synchronizovať</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="900"/>
        <source>Select to copy/sync Shared</source>
        <translation>Zvoľte kopírovať/synchronizovať Zdieľané</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="903"/>
        <source>Shared folder</source>
        <translation>Zdieľaná zložka</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="916"/>
        <source>Select to copy/sync entire home</source>
        <translation>Zvoľte kopírovať/synchronizovať kompletnú home zložku</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="919"/>
        <source>Entire home</source>
        <translation>Kopletná home zložka</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="935"/>
        <source>Select to copy/sync the browser configuration</source>
        <translation>Zvoľte kopírovať/synchronizovať konfiguráciu prehliadača</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="938"/>
        <source>Mozilla (Firefox or Iceweasel) configs</source>
        <translation>Konfigurácía Mozilla (Iceweasel alebo Firefox)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="951"/>
        <source>Select to copy/sync Documents</source>
        <translation>Zvoľte kopírovať/synchronizovať zložku Dokumenty</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="954"/>
        <source>Documents folder</source>
        <translation>Zložka Dokumenty</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="961"/>
        <source>What to copy/sync:</source>
        <translation>Čo sa bude kopírovať/synchronizovať:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="977"/>
        <source>Progress</source>
        <translation>Progres</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1007"/>
        <location filename="../mainwindow.ui" line="1023"/>
        <source>Status of the changes</source>
        <translation>Stav zmien</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1026"/>
        <source>Status:</source>
        <translation>Stav:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1042"/>
        <source>Progress of the changes</source>
        <translation>Progres zmien</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1079"/>
        <source>Add/Remove Groups</source>
        <translation>Vytvoriť/Odstrániť Skupiny</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1091"/>
        <source>Add Group</source>
        <translation>Vytvoriť Skupinu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1121"/>
        <source>Group name:</source>
        <translation>Názov skupiny:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1140"/>
        <source>groupname</source>
        <translation>groupname</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1169"/>
        <source>Delete Group</source>
        <translation>Odstrániť Skupinu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1231"/>
        <source>Group to delete:</source>
        <translation>Skupina k zmazaniu:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1259"/>
        <source>Group Membership</source>
        <translation>Členstvo v skupine</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1375"/>
        <source>Groups user belongs to (change the groups by selecting/deselecting the appropriate boxes):</source>
        <translation>Skupiny ku ktorým je užívateľ priradený (skupiny zmeníte vybratím/odvybratím odpovedajúcich políčok):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1395"/>
        <source>*Please doublecheck your selections before applying, assigning wrong group memberships can break your system.  Use Repair tab to restore the original memberships if you made a mistake.</source>
        <translation>*Pred zavedením zmien prosím skontrolujte svoje voľby, priradením užívateľa k nesprávnej skupine môžete poškodiť Váš systém. Ak ste už spravili chybu, použite záložku Opraviť pre obnovenie pôvodného členstva.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1455"/>
        <source>Apply any changes</source>
        <translation>Použiť všetky zmeny</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1458"/>
        <source>Apply</source>
        <translation>Použiť</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1465"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1472"/>
        <source>Cancel any changes then quit</source>
        <translation>Zrušit všetky zmeny a ukončiť</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1475"/>
        <source>Close</source>
        <translation>Zatvoriť</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1482"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1523"/>
        <source>Display help </source>
        <translation>Zobraziť nápovedu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1526"/>
        <source>Help</source>
        <translation>Pomocník</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1533"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1540"/>
        <source>About this application</source>
        <translation>O tejto aplikácii</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1543"/>
        <source>About...</source>
        <translation>O Programe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1550"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="111"/>
        <location filename="../mainwindow.cpp" line="143"/>
        <location filename="../mainwindow.cpp" line="151"/>
        <location filename="../mainwindow.cpp" line="164"/>
        <location filename="../mainwindow.cpp" line="175"/>
        <location filename="../mainwindow.cpp" line="184"/>
        <location filename="../mainwindow.cpp" line="193"/>
        <location filename="../mainwindow.cpp" line="617"/>
        <location filename="../mainwindow.cpp" line="634"/>
        <location filename="../mainwindow.cpp" line="665"/>
        <location filename="../mainwindow.cpp" line="674"/>
        <location filename="../mainwindow.cpp" line="819"/>
        <location filename="../mainwindow.cpp" line="932"/>
        <source>none</source>
        <translation>nič</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="205"/>
        <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
        <translation>Konfigurácia užívateľa bude opravená. Prosím zavrite všetky bežiace aplikácie. Po skončení operácie sa prosím odhláste alebo reštartujte PC. Skutočne si prajete spustiť opravu?  </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="226"/>
        <source>User group membership was restored.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="233"/>
        <source>Mozilla settings were reset.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="238"/>
        <location filename="../mainwindow.cpp" line="249"/>
        <source>Autologin options</source>
        <translation>Možnosti automatického prihlasovania</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="239"/>
        <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
        <translation>Automatické prihlásenie pre užívateľské konto &apos;%1&apos; bolo vypnuté. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="250"/>
        <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
        <translation>Automatické prihlásenie pre užívateľské konto &apos;%1&apos; bolo zapnuté. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
        <translation>Musíte zadať umiestnenie &apos;kopírovať do&apos;. Nedá sa kopírovať plocha pod ktorou ste prihlásení.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="266"/>
        <source>Before copying, close all other applications. Be sure the copy to destination is large enough to contain the files you are copying. Copying between desktops may overwrite or delete your files or preferences on the destination desktop. Are you sure you want to proceed?</source>
        <translation>Pred kopírovaním ukončite všetky bežiace aplikácie. Uistite sa, že zvolené umiestnenie pre kopírovanie má dostatočnú kapacitu pre skopírovanie zvolených súborov. Kopírovanie medzi kontami môže prepísať alebo zmazať súbory alebo nastavenia v cieľovej ploche. Prajete si pokračovať?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="291"/>
        <source>Synchronizing desktop...</source>
        <translation>Synchronizuje sa plocha...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="293"/>
        <source>Copying desktop...</source>
        <translation>Kopíruje sa plocha...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="314"/>
        <location filename="../mainwindow.cpp" line="509"/>
        <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Meno užívateľa musí mať dĺžku aspoň 2 znaky. Prosím vyberte dlhšie meno a pokračujte. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <location filename="../mainwindow.cpp" line="513"/>
        <source>The user name needs to be lower case and it
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Meno užívateľa musí pozostávať iba z malých písmen 
a mesmie obsahovať špeciálne znaky a medzery.
Prosím vyberte iné meno a pokračujte. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="327"/>
        <source>Sorry, this name is in use. Please enter a different name.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="332"/>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>Password entries do not match. Please try again.</source>
        <translation>Heslá sa nezhodujú. Prosím skúste to znovu.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="337"/>
        <location filename="../mainwindow.cpp" line="372"/>
        <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
        <translation>Heslo musí mať dĺžku aspoň 2 znaky. Prosím vyberte dlhšie heslo a pokračujte. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="354"/>
        <source>The user was added ok.</source>
        <translation>Užívateľ bol v poriadku vytvorený.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="358"/>
        <source>Failed to add the user.</source>
        <translation>Uźívateľa sa nepodarilo vytvoriť.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="386"/>
        <source>Password successfully changed.</source>
        <translation>Heslo bolo úspešne zmenené.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="390"/>
        <source>Failed to change password.</source>
        <translation>Heslo nebolo zmenené.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="396"/>
        <source>This action cannot be undone. Are you sure you want to delete user %1?</source>
        <translation>Táto akcia sa nedá zvrátiť. Skutočne si prajete zmazať konto užívateľa %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="409"/>
        <source>The user has been deleted.</source>
        <translation>Užívateľ bol odstránený.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="412"/>
        <source>Failed to delete the user.</source>
        <translation>Užívateľ nebol odstránený.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="426"/>
        <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Názov skupiny musí mať dĺžku aspoň 2 znaky. Prosím vyberte dlhší názov a pokračujte. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="430"/>
        <source>The group name needs to be lower case and it 
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Názov skupiny musí pozostávať iba z malých písmen 
a mesmie obsahovať špeciálne znaky a medzery.
Prosím vyberte iný názov a pokračujte. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="439"/>
        <source>Sorry, that group name already exists. Please enter a different name.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="446"/>
        <source>The system group was added ok.</source>
        <translation>Skupina bola v poriadku vytvorená.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="449"/>
        <source>Failed to add the system group.</source>
        <translation>Skupina nebola vytvorená.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="452"/>
        <source>This action cannot be undone. Are you sure you want to delete group %1?</source>
        <translation>Táto akcia sa nedá zvrátiť. Skutočne si prajete zmazať skupinu %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="459"/>
        <source>The group has been deleted.</source>
        <translation>Skupina bola odstránená.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="462"/>
        <source>Failed to delete the group.</source>
        <translation>Skupina nebola odstránená.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="484"/>
        <source>The changes have been applied.</source>
        <translation>Zmeny boli prevedené.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="487"/>
        <source>Failed to apply group changes</source>
        <translation>Zmeny neboli prevedené.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="500"/>
        <source>The selected user name is currently in use.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="501"/>
        <source>To rename this user, please log out and log back in using another user account.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="522"/>
        <source>Sorry, this name already exists on your system. Please enter a different name.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="530"/>
        <source>Failed to rename the user. Please make sure that the user is not logged in, you might need to restart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="544"/>
        <source>The user was renamed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="557"/>
        <location filename="../mainwindow.cpp" line="586"/>
        <source>Synchronizing desktop...ok</source>
        <translation>Synchronizuje sa plocha...ok</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="559"/>
        <location filename="../mainwindow.cpp" line="588"/>
        <source>Copying desktop...ok</source>
        <translation>Kopíruje sa plocha...ok</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="592"/>
        <source>Synchronizing desktop...failed</source>
        <translation>Synchronizuje sa plocha...zlyhalo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="594"/>
        <source>Copying desktop...failed</source>
        <translation>Kopíruje sa plocha...zlyhalo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="611"/>
        <location filename="../mainwindow.cpp" line="871"/>
        <location filename="../mainwindow.cpp" line="879"/>
        <source>browse...</source>
        <translation>prehľadať...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="782"/>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="783"/>
        <source>Version: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="787"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="802"/>
        <source>%1 Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About MX User Manager</source>
        <translation type="vanished">O programe MX Správca Užívateľov</translation>
    </message>
    <message>
        <source>MX User Manager</source>
        <translation type="vanished">MX Správca Užívateľov</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="784"/>
        <source>Simple user configuration for MX Linux</source>
        <translation>Jednoduchá správa užívateľov pre MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="786"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Licencia</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">História zmien</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Zrušiť</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Zatvoriť</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="872"/>
        <source>Select folder to copy to</source>
        <translation>Vyberte zložku do ktorej sa bude kopírovať</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="41"/>
        <source>You must run this program as root.</source>
        <translation>Tento program musíte spustiť ako root užívateľ.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation type="unfinished">Licencia</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation type="unfinished">História zmien</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation type="unfinished">Zrušiť</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Zatvoriť</translation>
    </message>
</context>
</TS>
